@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from AMS import AmsAgentDescription
 from DF import DfAgentDescription, ServiceDescription, Service
 from Agent import PlatformAgent, require_login
@@ -26,10 +27,13 @@ import BasicFipaDateTime
 from wui import *
 from os.path import *
 
-class PlatformRestart(Exception):
-    def __init__(self): pass
-    def __str__(self): return
 
+class PlatformRestart(Exception):
+    def __init__(self):
+        pass
+
+    def __str__(self):
+        return
 
 
 class SpadePlatform(PlatformAgent):
@@ -42,8 +46,8 @@ class SpadePlatform(PlatformAgent):
 
         def _process(self):
             msg = self._receive(True)
-            if (msg != None):
-                self.myAgent.DEBUG("SPADE Platform Received a message: " + str(msg),'info')
+            if (msg is not None):
+                self.myAgent.DEBUG("SPADE Platform Received a message: " + str(msg), 'info')
                 if msg.getSender() == self.myAgent.getAID():
                     # Prevent self-loopholes
                     self.myAgent.DEBUG("ACC LOOP HOLE", "warn")
@@ -55,15 +59,15 @@ class SpadePlatform(PlatformAgent):
                 for to in to_list:
                     if (self.myAgent.getAID().getName() != to.getName()):
                         if not to.getAddresses()[0] in d:
-                            d[to.getAddresses()[0]]=list()
+                            d[to.getAddresses()[0]] = list()
                         d[to.getAddresses()[0]].append(to)
-                for k,v in d.items():
+                for k, v in d.items():
                     newmsg = msg
                     newmsg.to = v
                     try:
                         protocol, receiver_URI = k.split("://")
                     except:
-                        self.myAgent.DEBUG("Malformed Agent Address URI: " + str(k),"error")
+                        self.myAgent.DEBUG("Malformed Agent Address URI: " + str(k), "error")
                         break
 
                     # Check if one of our MTPs handles this protocol
@@ -86,15 +90,15 @@ class SpadePlatform(PlatformAgent):
                         self.myAgent.mtps[protocol].send(envelope, payload)
                     else:
                         # Default case: it's an XMPP message
-                        self.myAgent.DEBUG("Message through protocol XMPP",'info')
-                        platform = self.myAgent.getSpadePlatformJID().split(".",1)[1]
+                        self.myAgent.DEBUG("Message through protocol XMPP", 'info')
+                        platform = self.myAgent.getSpadePlatformJID().split(".", 1)[1]
                         if not platform in receiver_URI:
                             # Outside platform
-                            self.myAgent.DEBUG("Message for another platform",'info')
+                            self.myAgent.DEBUG("Message for another platform", 'info')
                             self.myAgent.send(newmsg, "jabber")
                         else:
                             # THIS platform
-                            self.myAgent.DEBUG("Message for current platform",'info')
+                            self.myAgent.DEBUG("Message for current platform", 'info')
                             for recv in v:
                                 #self.myAgent._sendTo(newmsg, recv.getName(), "jabber")
                                 self.myAgent.send(newmsg, "jabber")
@@ -110,7 +114,8 @@ class SpadePlatform(PlatformAgent):
                     #print "Message to", to.getName(), "... Posting!"
                     """
             else:
-                self.myAgent.DEBUG("ACC::dying... this shouldn't happen", 'err')
+                pass
+                ##self.myAgent.DEBUG("ACC::dying... this shouldn't happen", 'err')
 
     def __init__(self, node, password, server, port, config=None):
         PlatformAgent.__init__(self, node, password, server, port, config=config, debug=[])
@@ -119,54 +124,40 @@ class SpadePlatform(PlatformAgent):
     def _setup(self):
         self.setDefaultBehaviour(self.RouteBehaviour())
 
-        self.wui.registerController("index",self.index)
+        self.wui.registerController("index", self.index)
         self.wui.registerController("agents", self.agents)
         self.wui.registerController("services", self.services)
         self.wui.setPort(8008)
         self.wui.start()
-        
+
+	import mtp
         # Load MTPs
-        for name,mtp in self.config.acc.mtp.items():
-        #self.mtps[mtp.protocol] = mtp.instance(name)
+        for name, _mtp in self.config.acc.mtp.items():
             try:
-                 mtp_path = "."+os.sep+"spade"+os.sep+"mtp"
-                 if os.path.exists(mtp_path):
-                      sys.path.append(mtp_path)
-                 else:
-                    # This path should come from the config file . . .
-                      mtp_path = os.sep+"usr"+os.sep+"share"+os.sep+"spade"+os.sep+"mtp"
-                      sys.path.append(mtp_path)
-
-                 mod = __import__(name)
-                 self.mtps[mtp['protocol']] = mod.INSTANCE(name,self.config,self)
-
+                mod = "mtp."+name
+                mod = __import__(mod, globals(), locals(),[name])
+                self.mtps[_mtp['protocol']] = mod.INSTANCE(name, self.config, self)
             except Exception, e:
-                print "EXCEPTION IMPORTING MTPS: ",str(e)
-                _exception = sys.exc_info()
-                if _exception[0]:
-                     msg='\n'+''.join(traceback.format_exception(_exception[0], _exception[1], _exception[2])).rstrip()
-                     print msg
+                self.DEBUG("EXCEPTION IMPORTING MTPS: "+ str(e), 'err','acc')
 
     def takeDown(self):
-        for k,mtp in self.mtps.items():
+        for k, _mtp in self.mtps.items():
             try:
-                mtp.stop()
+                _mtp.stop()
                 del self.mtps[k]
             except:
                 pass
 
-
-
     #Controllers
     def index(self):
         import sys
         import time
         servername = self.getDomain()
-        platform = self.getName()        
+        platform = self.getName()
         version = str(sys.version)
         the_time = str(time.ctime())
         doc_path = abspath('.')
-        return "webadmin_indigo.pyra", dict(name=platform,servername=servername, platform=platform, version=version, time=the_time, doc_path=doc_path)
+        return "webadmin_indigo.pyra", dict(name=platform, servername=servername, platform=platform, version=version, time=the_time, doc_path=doc_path)
 
     @require_login
     def agents(self):
@@ -174,7 +165,7 @@ class SpadePlatform(PlatformAgent):
         import time
         so = self.session
         servername = self.getDomain()
-        platform = self.getName()        
+        platform = self.getName()
         version = str(sys.version)
         the_time = str(time.ctime())
         search = self.searchAgent(AmsAgentDescription())
@@ -189,23 +180,23 @@ class SpadePlatform(PlatformAgent):
             for agent in search:
                 if agent.getAID():
                     aw = "#"
-                    for addr in agent.getAID().getAddresses():                    
+                    for addr in agent.getAID().getAddresses():
                         if "awui://" in addr:
                             aw = addr.replace("awui://", "http://")
                             break
                     awuis[agent.getAID().getName()] = aw
-        self.DEBUG("AWUIs: "+str(awuis))
-        return "agents.pyra", dict(name=platform,servername=servername, platform=platform, version=version, time=the_time, agents=search, awuis=awuis)
+        self.DEBUG("AWUIs: " + str(awuis))
+        return "agents.pyra", dict(name=platform, servername=servername, platform=platform, version=version, time=the_time, agents=search, awuis=awuis)
 
     @require_login
     def services(self):
         import sys
         import time
         servername = self.getDomain()
-        platform = self.getName()        
+        platform = self.getName()
         version = str(sys.version)
         the_time = str(time.ctime())
-        try:        
+        try:
             search = self.searchService(DfAgentDescription())
         except Exception, e:
             print "Exception: " + str(e)
@@ -219,27 +210,9 @@ class SpadePlatform(PlatformAgent):
                 s = Service(dad=new_dad)
                 servs[service.getType()].append(s)
         self.DEBUG("Services: " + str(servs))
-        return "services.pyra", dict(name=platform,servername=servername, platform=platform, version=version, time=the_time, services=servs)
+        return "services.pyra", dict(name=platform, servername=servername, platform=platform, version=version, time=the_time, services=servs)
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-    def getMembers(self,aname):
+    def getMembers(self, aname):
         msg = ACLMessage.ACLMessage()
         msg.setOntology("spade:x:organization")
         template = Behaviour.ACLTemplate()
@@ -248,23 +221,18 @@ class SpadePlatform(PlatformAgent):
         b = self.GetMembersBehav()
         b.msg = msg
         b.aname = aname
-        self.addBehaviour(b,t)
+        self.addBehaviour(b, t)
         b.join()
         return b.result
 
     class GetMembersBehav(Behaviour.OneShotBehaviour):
         def _process(self):
             self.result = []
-	    self.msg.addReceiver(AID.aid(self.aname, addresses=["xmpp://"+self.aname]))
-	    self.msg.setContent("MEMBERS")
-	    self.myAgent.send(self.msg)
-	    rep = None
-	    rep = self._receive(True, 20)
-	    if rep:
-	        print "The members list arrived"
-	        self.result = rep.getContent().split(",")
-
-
-
-
-
+            self.msg.addReceiver(AID.aid(self.aname, addresses=["xmpp://" + self.aname]))
+            self.msg.setContent("MEMBERS")
+            self.myAgent.send(self.msg)
+            rep = None
+            rep = self._receive(True, 20)
+            if rep:
+                print "The members list arrived"
+                self.result = rep.getContent().split(",")
