@@ -1,5 +1,5 @@
 #! python
-# -*- coding: cp1252 -*-
+# -*- coding: utf-8 -*-
 import sys
 
 
@@ -19,9 +19,9 @@ from spade import MessageReceiver
 from spade import pyparsing
 from spade import SL0Parser
 from spade import XMLCodec
-from spade import SpadeConfigParser 
+from spade import SpadeConfigParser
+
 
-    
 class SpadeBackend:
     """
     Runs the platform.
@@ -35,49 +35,55 @@ class SpadeBackend:
         #jid = configfile.get(section,'JID')
         passwd = config[section]['password']
         server = config["platform"]['hostname']
-        port = int( config[section]['port'] )
+        port = int(config[section]['port'])
         jid = section + "." + server
-        if not "adminpasswd" in config.keys(): config["adminpasswd"]=None
+        if not "adminpasswd" in config.keys():
+            config["adminpasswd"] = None
         if section == "acc":
             agent = agentClass(jid, passwd, server, port, config=config)
         else:
             agent = agentClass(jid, passwd, server, port)
-            agent.setAdminPasswd(config["adminpasswd"])
+        agent.setAdminPasswd(config["adminpasswd"])
         agent.start()
         return agent
-    
-    def __init__(self, configfilename="/etc/spade/spade.xml"):
+
+    def __init__(self, configfilename="spade.xml"):
         parser = SpadeConfigParser.ConfigParser()
         self.config = parser.parse(configfilename)
-        self.ams=None
-        self.df =None
-        self.acc=None     
+        self.ams = None
+        self.df = None
+        self.acc = None
         self.alive = True  # Alive flag
 
     def start(self):
         #TODO: this should be configurable
         self.acc = self.runAgent(self.config, "acc", Platform.SpadePlatform)
-        #self.acc._debug=True
+        #self.acc.setDebugToScreen()
         self.ams = self.runAgent(self.config, "ams", AMS.AMS)
-        #self.ams.DEBUG = self.acc.DEBUG
+        self.ams.DEBUG = self.acc.DEBUG
+        #self.ams.setDebugToScreen()
         self.df = self.runAgent(self.config, "df", DF.DF)
-        #self.df.DEBUG = self.acc.DEBUG
-        #self.simba = self.runAgent(self.configfile, "simba", SIMBA.SIMBA)        
+        self.df.DEBUG = self.acc.DEBUG
+        #self.df.setDebugToScreen()
+        #self.simba = self.runAgent(self.configfile, "simba", SIMBA.SIMBA)
 
     def shutdown(self):
         if self.df:
-		    self.df.stop()
-		    del self.df
-        if self.ams: 
-		    self.ams.stop()
-		    del self.ams
+            self.df.stop()
+            #del self.df
+            self.DEBUG("DF agent terminated.")
+        if self.ams:
+            self.ams.stop()
+            #del self.ams
+            self.DEBUG("AMS agent terminated.")
         if self.acc:
-		    self.acc.stop()
-		    del self.acc
-		    
-    def DEBUG(self,component="",msg="",typ=""):
-	    self.acc.DEBUG(msg,typ,component)
+            self.acc.stop()
+            self.DEBUG("ACC agent terminated.")
+            #del self.acc
 
-if __name__ ==  "__main__":
-	p = SpadeBackend()
-	p.start()
+    def DEBUG(self, component="", msg="", typ=""):
+        self.acc.DEBUG(msg, typ, component)
+
+if __name__ == "__main__":
+    p = SpadeBackend()
+    p.start()
