@@ -1,4 +1,4 @@
-# encoding: UTF-8
+# -*- coding: utf-8 -*-
 import traceback
 import SocketServer
 import SimpleHTTPServer
@@ -13,116 +13,138 @@ import random
 import socket
 import Cookie
 import string
+import time
 
 from threading import Thread
 
 chars = string.ascii_letters + string.digits
-sessionDict = {} # dictionary mapping session id's to session objects
+sessionDict = {}  # dictionary mapping session id's to session objects
+
 
 class HTTP_REDIRECTION(Exception):
     pass
 
+
 class WUI(Thread):
     def __init__(self, owner):
         Thread.__init__(self)
+        self.setName("WUI " + str(owner.getName()))
         self.owner = owner
         self.httpd = None
         self.port = 8009
-        self.template_path = "" 
+        self.template_path = ""
         # Try to get SPADE's default template path
         tpath = os.path.realpath(pyratemp.__file__)  # /Users/foo/devel/trunk/spade
-        tpath = tpath.rsplit(os.sep,1)  # ["/Users/foo/devel/trunk", "spade"]
-        self.spade_path = tpath[0]    ###+os.sep+os.pardir
+        tpath = tpath.rsplit(os.sep, 1)  # ["/Users/foo/devel/trunk", "spade"]
+        self.spade_path = tpath[0]  # +os.sep+os.pardir
         #self.owner.DEBUG("SPADE path: " + self.spade_path,"warn")
-        
+
         self.controllers = {}
-        
+
         self.is_running = False
 
     def run(self):
+        timeout = 5
+        while self.httpd is None and timeout > 0:
+            try:
+                SocketServer.ThreadingTCPServer.allow_reuse_address = True
+                self.httpd = SocketServer.ThreadingTCPServer(('', self.port), WUIHandler)
+                self.httpd.owner = self
+                self.httpd.timeout = 1
+            except Exception, e:
+                self.port = random.randint(1024, 65536)
+            timeout -= 1
+            time.sleep(1)
 
-        while not self.httpd:
-             try:
-                 self.httpd = SocketServer.ThreadingTCPServer(('', self.port), WUIHandler)
-                 self.httpd.owner = self
-                 self.httpd.timeout = 1
-                 #print "WebUserInterface serving at port "+str(self.port)
-                 self.notifyAMS()
-             except:
-                 self.port = random.randint(1024,65536)
-                 
-        self.owner.DEBUG("WebUserInterface serving at port "+str(self.port))
-        self.registerController("error404", self.error404)
-        self.registerController("error501", self.error501)
-        self.registerController("error503", self.error503)
+        if self.httpd is not None:
+            self.owner.DEBUG("WebUserInterface serving at port " + str(self.port))
+            self.registerController("error404", self.error404)
+            self.registerController("error501", self.error501)
+            self.registerController("error503", self.error503)
 
-        self.is_running = True
-        while self.isRunning():
-            self.httpd.handle_request()
+            self.notifyAMS()
+
+            self.is_running = True
+            self.httpd.serve_forever(poll_interval=0.5)
+            self.owner.DEBUG("WebUserInterface(" + str(self.port) + ") finished", 'ok')
+        else:
+            self.owner.DEBUG("Could not set up WebUserInterface! at port " + str(self.port), 'err')
 
     def isRunning(self):
         return self.is_running
-        
+
     def stop(self):
         self.is_running = False
-        
+        if self.httpd is not None:
+            try:
+                self.httpd.shutdown()
+                self.httpd.server_close()
+            except Exception, e:
+                pass
+            self.httpd = None
+
     def setPort(self, port):
         self.port = port
-        
-    def setTemplatePath(self,path):
+
+    def setTemplatePath(self, path):
         self.template_path = os.path.realpath(path)
-        
+
     def registerController(self, name, controller):
         self.controllers[name] = controller
-            
+
     def unregisterController(self, name):
         del self.controllers[name]
-    
+
     def notifyAMS(self):
         """Notify AMS of current AWUI URL"""
         #return
         from spade.AMS import AmsAgentDescription
         aad = AmsAgentDescription()
         aid = self.owner.getAID()
-        aid.addAddress("awui://"+str(socket.gethostbyname(socket.gethostname()))+":"+str(self.port))
+        aid.addAddress("awui://" + str(socket.gethostbyname(socket.gethostname())) + ":" + str(self.port))
         aad.setAID(aid)
         self.owner.modifyAgent(aad)
-        
+
     #Controllers
 
     def error404(self):
-        return "404.pyra", {"template":"404.pyra"}
+        return "404.pyra", {"template": "404.pyra"}
+
     def error501(self):
-        return "501.pyra", {"template":"501.pyra", "error":""}
+        return "501.pyra", {"template": "501.pyra", "error": ""}
+
     def error503(self):
-        return "503.pyra", {"page":"503.pyra"}
+        return "503.pyra", {"page": "503.pyra"}
 
 
 class SessionElement(object):
-   """Arbitrary objects, referenced by the session id"""
-   pass
+    """Arbitrary objects, referenced by the session id"""
+    pass
+
 
 def generateRandom(length):
-   """Return a random string of specified length (used for session id's)"""
-   return ''.join([random.choice(chars) for i in range(length)])
+    """Return a random string of specified length (used for session id's)"""
+    return ''.join([random.choice(chars) for i in range(length)])
+
 
 class WUIHandler(SimpleHTTPServer.SimpleHTTPRequestHandler):
 
-    def log_message(format,*args): pass
+    def log_message(format, *args):
+        pass
 
     def Session(self):
         """Session management
-        If the client has sent a cookie named sessionId, take its value and 
-        return the corresponding SessionElement objet, stored in 
+        If the client has sent a cookie named sessionId, take its value and
+        return the corresponding SessionElement objet, stored in
         sessionDict
         Otherwise create a new SessionElement objet and generate a random
         8-letters value sent back to the client as the value for a cookie
         called sessionId"""
-        if self.cookie.has_key("sessionId"):
-            sessionId=self.cookie["sessionId"].value
+        if "sessionId" in self.cookie:
+            sessionId = self.cookie["sessionId"].value
         else:
-            sessionId=generateRandom(8)
-            self.cookie["sessionId"]=sessionId
+            sessionId = generateRandom(8)
+            self.cookie["sessionId"] = sessionId
         try:
             sessionObject = sessionDict[sessionId]
         except KeyError:
@@ -176,7 +198,6 @@ class WUIHandler(SimpleHTTPServer.SimpleHTTPRequestHandler):
 
         self.do_GET()
 
-
     def do_GET(self):
         """
         GET petitions handler
@@ -184,32 +205,34 @@ class WUIHandler(SimpleHTTPServer.SimpleHTTPRequestHandler):
         ret = None
         request = self.raw_requestline.split()
         page = self.getPage(request[1])
-    
 
-        if page == "/": page = "/index"
+        if page == "/":
+            page = "/index"
+
+        if page.startswith("/"):
+            page = page[1:]
 
-        if page.startswith("/"): page = page [1:]
-        
         try:
-            req_vars = self.getVars("?"+self._POST_REQ)
+            req_vars = self.getVars("?" + self._POST_REQ)
         except:
             req_vars = self.getVars(request[1])
-        
-        s_vars=""
-        for k,v in req_vars.items():
+
+        s_vars = ""
+        for k, v in req_vars.items():
             if k:
                 v = str(v)
                 if not v.startswith('"') and not v.startswith("'") and not v.startswith("["):
-                    v = '"'+ v +'"'
-                s_vars+= str(k) + "=" + v +","
-        if s_vars.endswith(","): s_vars = s_vars[:-1]
+                    v = '"' + v + '"'
+                s_vars += str(k) + "=" + v + ","
+        if s_vars.endswith(","):
+            s_vars = s_vars[:-1]
 
         #session management
-        if self.headers.has_key('cookie'):
-            self.cookie=Cookie.SimpleCookie(self.headers.getheader("cookie"))
+        if 'cookie' in self.headers:
+            self.cookie = Cookie.SimpleCookie(self.headers.getheader("cookie"))
         else:
-            self.cookie=Cookie.SimpleCookie()
-            
+            self.cookie = Cookie.SimpleCookie()
+
         # Switch page
         #if page.endswith("css"):
         if page.endswith(".css") or page.endswith(".png") or page.endswith(".html") or page.endswith(".js"):
@@ -226,42 +249,42 @@ class WUIHandler(SimpleHTTPServer.SimpleHTTPRequestHandler):
                     raise Exception
 
             except:
-                self.server.owner.owner.DEBUG("Could not open file: "+ page, "err")
+                self.server.owner.owner.DEBUG("Could not open file: " + page, "err")
 
             try:
-                    self.send_response(200)
-                    for morsel in self.cookie.values():
-                        self.send_header('Set-Cookie', morsel.output(header='').lstrip())
-                    self.end_headers()
-                    f = open(page, "r")
-                    self.copyfile(f, self.wfile)
-                    f.close()
+                self.send_response(200)
+                for morsel in self.cookie.values():
+                    self.send_header('Set-Cookie', morsel.output(header='').lstrip())
+                self.end_headers()
+                f = open(page, "r")
+                self.copyfile(f, self.wfile)
+                f.close()
             except:
-                    self.server.owner.owner.DEBUG(str(sys.exc_info()), "err")
-        
+                self.server.owner.owner.DEBUG(str(sys.exc_info()), "err")
+
         else:
             sess = self.Session()
             try:
                 # Check wether controller exists
                 # Get the first section of the URL path (e.g. the "admin" of "admin/foo/bar")
-                eval("self.server.owner.controllers['"+str(page)+"']")
+                eval("self.server.owner.controllers['" + str(page) + "']")
             except:
                 # The controller doesn't exist
                 _exception = sys.exc_info()
                 if _exception[0]:
                     _err = ''.join(traceback.format_exception(_exception[0], _exception[1], _exception[2])).rstrip()
                 template = "404.pyra"
-                ret = {"template":page, "error":str(_err),"name":self.server.owner.owner.getName()}
-                code=404
+                ret = {"template": page, "error": str(_err), "name": self.server.owner.owner.getName()}
+                code = 404
             try:
                 if not ret:
                     func = self.server.owner.controllers[str(page)]
                     #session object
                     sess.url = page
                     func.__self__.session = sess
-                    template, ret = eval("func"+"("+s_vars+")")
-                    code=200
-            except HTTP_REDIRECTION,url:
+                    template, ret = eval("func" + "(" + s_vars + ")")
+                    code = 200
+            except HTTP_REDIRECTION, url:
                 self.send_response(302)
                 for morsel in self.cookie.values():
                     self.send_header('Set-Cookie', morsel.output(header='').lstrip())
@@ -276,36 +299,37 @@ class WUIHandler(SimpleHTTPServer.SimpleHTTPRequestHandler):
                 if _exception[0]:
                     _err = ''.join(traceback.format_exception(_exception[0], _exception[1], _exception[2])).rstrip()
                 template = "501.pyra"
-                ret = {"template":page, "error":str(_err),"name":self.server.owner.owner.getName()}
-                code=501
-            
+                ret = {"template": page, "error": str(_err), "name": self.server.owner.owner.getName()}
+                code = 501
+
             try:
-                if os.path.exists(self.server.owner.template_path+os.sep+template):
-                    t = pyratemp.Template(filename=self.server.owner.template_path+os.sep+template, data=ret)
+                if os.path.exists(self.server.owner.template_path + os.sep + template):
+                    t = pyratemp.Template(filename=self.server.owner.template_path + os.sep + template, data=ret)
                 else:
                     #olddir = os.path.curdir
                     #os.chdir(self.server.spade_path)
                     authenticated = False
-                    if hasattr(sess,"user_authenticated"):
-                        if sess.user_authenticated==True: authenticated=True
+                    if hasattr(sess, "user_authenticated"):
+                        if sess.user_authenticated is True:
+                            authenticated = True
                     ret['authenticated'] = authenticated
-                    t = pyratemp.Template(filename=self.server.owner.spade_path+os.sep+"templates"+os.sep+template, data=ret)
+                    t = pyratemp.Template(filename=self.server.owner.spade_path + os.sep + "templates" + os.sep + template, data=ret)
                     #print template, ret
                     #os.chdir(olddir)
             except pyratemp.TemplateSyntaxError, e:
                 _exception = sys.exc_info()
                 if _exception[0]:
                     _err = ''.join(traceback.format_exception(_exception[0], _exception[1], _exception[2])).rstrip()
-                t = pyratemp.Template(filename=self.server.owner.spade_path+os.sep+"templates"+os.sep+"501.pyra", data={"template":template, "error":str(_err),"name":self.server.owner.owner.getName()})
-                code=501
+                t = pyratemp.Template(filename=self.server.owner.spade_path + os.sep + "templates" + os.sep + "501.pyra", data={"template": template, "error": str(_err), "name": self.server.owner.owner.getName()})
+                code = 501
             except Exception, e:
                 #No template
                 _exception = sys.exc_info()
                 if _exception[0]:
                     _err = ''.join(traceback.format_exception(_exception[0], _exception[1], _exception[2])).rstrip()
                 #print "###", _err, "###"
-                t = pyratemp.Template(filename=self.server.owner.spade_path+os.sep+"templates"+os.sep+"503.pyra", data={"page":template,"name":self.server.owner.owner.getName()})
-                code=503
+                t = pyratemp.Template(filename=self.server.owner.spade_path + os.sep + "templates" + os.sep + "503.pyra", data={"page": template, "name": self.server.owner.owner.getName()})
+                code = 503
             try:
                 result = t()
             except Exception, e:
@@ -313,17 +337,14 @@ class WUIHandler(SimpleHTTPServer.SimpleHTTPRequestHandler):
                 _exception = sys.exc_info()
                 if _exception[0]:
                     _err = ''.join(traceback.format_exception(_exception[0], _exception[1], _exception[2])).rstrip()
-                t = pyratemp.Template(filename=self.server.owner.spade_path+os.sep+"templates"+os.sep+"501.pyra", data={"template":template, "error":str(_err),"name":self.server.owner.owner.getName()})
+                t = pyratemp.Template(filename=self.server.owner.spade_path + os.sep + "templates" + os.sep + "501.pyra", data={"template": template, "error": str(_err), "name": self.server.owner.owner.getName()})
                 result = t()
-                code=501
-                
+                code = 501
+
             r = result.encode("ascii", 'xmlcharrefreplace')
-            
+
             self.send_response(code)
             for morsel in self.cookie.values():
                 self.send_header('Set-Cookie', morsel.output(header='').lstrip())
             self.end_headers()
             self.wfile.write(r)
-
-
-
